import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createWearableType,
  getAllWearableTypes,
  getWearableTypeById,
  updateWearableTypeById,
} from "../../../controller/admin/unit/wearableTypeController";
import { deleteWearableById } from "../../../controller/admin/unit/wearableController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllWearableTypes(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getWearableTypeById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "unit", "wearable_type"),
  async (req: Request, res: Response) => {
    await createWearableType(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "wearable_type"),
  async (req: Request, res: Response) => {
    await updateWearableTypeById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "unit", "wearable_type"),
  async (req: Request, res: Response) => {
    await deleteWearableById(req, res);
  }
);

export default router;
